==> haskell-filelock-0.1.1.8-46.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.8
visibility:           public
id:                   filelock-0.1.1.8-90F8GZg133n2gbiAkChNY5
key:                  filelock-0.1.1.8-90F8GZg133n2gbiAkChNY5
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  266c92937e83a5579ae4cda0e73d4503
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.8-90F8GZg133n2gbiAkChNY5
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filelock-0.1.1.8-47-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.8
visibility:           public
id:                   filelock-0.1.1.8-Jbu16lZu6N3NkhqJBNYLr
key:                  filelock-0.1.1.8-Jbu16lZu6N3NkhqJBNYLr
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  4cce279b62db972e1a6d7de764b85cae
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.8-Jbu16lZu6N3NkhqJBNYLr
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
